import java.awt.*;
import java.awt.geom.*;
import javax.swing.*;
import java.util.*;

class RampChart extends JComponent
{
	private Vector<Integer> values;
	private int padding;

	public RampChart ()
	{
		values = new Vector<Integer>();
		padding = 10;
		setBorder(BorderFactory.createLoweredBevelBorder());
	}

	public void setPadding (int _padding)
	{
		padding = _padding;
	}

	public final int getPadding ()
	{
		return padding;
	}

	public final Vector<Integer> getValues ()
	{
		return values;
	}

	public void setValues (Vector<Integer> _values)
	{
		values = _values;
	}

	protected void paintComponent (Graphics g)
	{
		// Draw background if opaque.
		if (isOpaque()) {
			g.setColor(getBackground());
			g.fillRect(0, 0, getWidth(), getHeight());
		}
			
		if (!values.isEmpty()) {
			// Aquire an extended graphics device for drawing the chart.
			Graphics2D g2 = (Graphics2D) g.create();
		
			// Draw the upper line.
			g2.setPaint(Color.black);
			g2.setStroke(new BasicStroke(1.0f));
			g2.draw(new Line2D.Double(getPadding(), getPadding(),
				getWidth() - getPadding(), getPadding()));
			
			// Draw the lower line.
			g2.draw(new Line2D.Double(getPadding(),
				getHeight() - getPadding(),
				getWidth() - getPadding(), getHeight() - getPadding()));
			
			// Find the largest value that needs to be displayed.
			int maxValue = 0;
			for (Object o : values) {
				int value = (Integer) o;
				if (value > maxValue) {
					maxValue = value;
				}
			}

			int areaWidth = getWidth() - 2 * getPadding();
			int areaHeight = getHeight() - 2 * getPadding();

			int barWidth = areaWidth / values.size();
			int left = areaWidth % values.size();
			float scale = (getHeight() - 2 * getPadding()) / maxValue;

			for (int i = 0; i < values.size(); ++i) {
				int value = (Integer) values.get(i);

				g2.setPaint(Color.red);
				g2.fill(new Rectangle2D.Double(getPadding() + i * barWidth,
					areaHeight - value * scale + getPadding(),
					barWidth,
					value * scale));

				g2.setPaint(Color.black);
				g2.draw(new Rectangle2D.Double(getPadding() + i * barWidth,
					areaHeight - value * scale + getPadding(),
					barWidth,
					value * scale));
			}

			g2.dispose();
		}

	}
}
